"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const query_string_1 = require("query-string");
const lodash_reduce_1 = __importDefault(require("lodash.reduce"));
function ignoreDefaultQueryParameters(queryParams, defaultQueryParams) {
    // Remove all values from the queryParams which match the defaultQueryParams
    return lodash_reduce_1.default(queryParams, (result, value, key) => {
        if (value !== defaultQueryParams[key]) {
            result[key] = value;
        }
        return result;
    }, {});
}
/**
 * Takes a URL and query builder options and appends the query parameters
 * to the URL. It ignores query parameters which match the default query
 * parameters.
 *
 * @example
 * queryParamsBuilder({url: 'users/1', queryParams: { visible: true }, { defaultQueryParams: visible: false} }) === '/users/1?visible=true
 *
 * @param {String} options.url The url which get the query parameters appended.
 * @param {Object} options.queryParams The query params as an object.
 * @param {Object} options.defaultQueryParams The default query parameters.
 */
function queryParamsBuilder(options) {
    const { url, queryParams, defaultQueryParams } = options;
    const params = ignoreDefaultQueryParameters(queryParams, defaultQueryParams);
    const urlParams = query_string_1.stringify(params, { encode: false });
    if (urlParams) {
        return `${url}?${urlParams}`;
    }
    else {
        return url;
    }
}
exports.queryParamsBuilder = queryParamsBuilder;
